# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: blickfeld/diagnostics/config/self_test.proto
# plugin: python-betterproto
from dataclasses import dataclass

import blickfeld_qb2.betterproto as betterproto
import blickfeld_qb2.betterproto.lib.google.protobuf as betterproto_lib_google_protobuf


class SelfTest(betterproto.Enum):
    """
    List of available self tests NOTE: The test list is still incomplete.
    """

    SELF_TEST_UNSPECIFIED = 0
    """No test is specified."""

    SELF_TEST_POINT_CLOUD = 1
    """
    Simple test which starts up the device, requests a point cloud, validates
    its properties and stops the device.
    """

    SELF_TEST_CONNECTION = 2
    """
    Simple connection tests to basic peripherals: PCIe, laser, detector,
    vertical BDC & horizontal BDC. It performs version requests to the modules.
    """

    SELF_TEST_BEAM_DEFLECTION_UNIT = 3
    """Simple check for basic functionality of the beam deflection units"""
